1. Create a directory "nectar_skyy" under YOUR_SDK_ROOT\examples\peripheral\nectar_skyy (for example C:\nrF52_SDK_16\examples\peripheral\nectar_skyy)
2. Clone the repo 
3. Assuming you already have installed Segger Studio.. open the studio and open the solution
4. in SES, goto tools->options->Building->Global Macros and add an entry for the macro SDK with your SDK root directory (for example SDK=C:\nrF52_SDK_16)
5. You should be able to compile and build after this and if you have a board connected, you can flash/debug as well
6. UARTshould be configured to  115K baud, 8 bits, no parity, 1 stop bit and no flow control
 


API Definitions:

UART	
    //initialize the uart peripoheral
	void nectar_uart_init(void);
	
	//get ONE charecter frokm the terminal.. it will also print the charceter that was typed
	uint8_t nectar_uart_get_char(void);
	
	//simple bring up test to check basic working of uart wrapper
	bool nectar_uart_bringup_test(void);
	
	//uninit the peripheral before going to deep sleep or whenever uart is not needed.
	bool nectar_uart_uninit(void);
	
	
SPI	
    //read a register of the peripheral connected via spi
	uint8_t nectar_spi_readRegister8(uint8_t addr);
	
	//write into a register of the peripheral connected via spi
	void nectar_spi_writeRegister8(uint8_t addr, uint8_t value);
	
	//initialize the spi peripheral.. currently, spi is married to accel with predefined Chip select
	void nectar_spi_init(void);
	
	//called before system goes to deep sleep
	bool nectar_spi_sleep(void);
	
	
GPIO	
    //initialize the GPIO section of the MCU
	void nectar_gpio_init(void);
	
	//Enable all interrupts currently configured as GPIO input interrupts
	void nectar_gpio_intr_enable(void);
	
	//Enable interrupts for a specific pin
	void nectar_gpio_intr_enable_by_pin(nrfx_gpiote_pin_t pin);
	
	
	//Disable all interrupts currently configured as GPIO input interrupts
	void nectar_gpio_intr_disable(void);
	
	//Disable interrupts for a specific pin
	void nectar_gpio_intr_disable_by_pin(nrfx_gpiote_pin_t pin);
	
	
Accel	
    //initialize the accel LIS2DH12.. and based on stopper or pourer configure accordingly
	bool lis2dh12_init(void);
	
	//clear any accel interrupts
	void lis2dh12_clear_intr();
	
	//check accel status (source of interrupts, data ready etc)
	uint8_t lis2dh12_check_status(void);
	
	//streaming accel data continuously for testing or analysis
	void lis2dh12_read_xyz_data_and_print(void);
	
	//returns true if accel is vertical (with margin LISDH12_ANGLE_VERTICAL_MARGIN defined in nectar_skyy.h)
	bool lis2dh12_accel_vertical(void);
	
	//returns true if accel is stable.. vectar magnitude (ideally should be 1000mg) withint the range defined in nectar_skyy.h
	//LISDH12_VEC_MAG_MIN_STABLE - LISDH12_VEC_MAG_MAX_STABLE
	bool lis2dh12_accel_stable(void);

TWI (I2c)	
    //Initialize the TWI peripheral
	void nectar_twi_init(void);
	
	//Read specified length of data from a peripheral (gievn the address) via TWI
	bool nectar_nrf_twi_read(uint8_t address, uint8_t *p_data_rx, uint8_t length);
	
	//write specified length of fata into an external peripheral via TWI
	bool nectar_nrf_twi_write(uint8_t address, uint8_t *p_data_tx, uint8_t length, bool no_stop);
	
	//check if TWI is busy with some transactions. CXall this from applications before initiating a TWI transaction
	bool nectar_is_twi_busy(void);
	
	//get TWI ready for deep sleep
	bool nectar_twi_sleep(void);
	
	
EEPROM	
    //byte level read.. read n bytes
	eep_err_t read_n_bytes(uint16_t offset, uint8_t *data, uint8_t n_bytes);
	
	//byte level writes.. write n bytes
	eep_err_t write_n_bytes(uint16_t offset, uint8_t *data, uint8_t n_bytes);
	
	//erase the entire eeprom.. use VERY VERY carefully
	eep_err_t eep_erase_all(void);
	
	//erase one page
	eep_err_t erase_page(uint16_t page);
	
	//single byte access
	eep_err_t read_byte(uint16_t offset, uint8_t *data);
	eep_err_t write_byte(uint16_t offset, uint8_t data);
	
	//single page access
	eep_err_t write_page(uint16_t page, uint8_t *data);
	eep_err_t read_page(uint8_t page, uint8_t *data);
	
	
	//eeprom test routines
	//basic bringup test without RTC interrupt
	bool nectar_rtc_bringup_test(void);
	
	//bringup test with RTC interrupt
	bool nectar_rtc_interrupt_bringup_test();
	
	
	//APIs to get version and build changes
	bool skyy_fw_new_version(void);
	bool skyy_fw_new_build(void);
	
RTC	
    //Init RTC
	rtc_err_t nectar_rtc_init(void);
	
	//set timers in minutes
	bool nectar_rtc_set_timer_interrupt(uint16_t minutes, bool repeat);
	
	//read RTC time SS:MM:HH:DD:MM:YY
	bool nectar_rtc_read_time(void);
	
	//check and clear RTC status register
	uint8_t nectar_rtc_check_status(void);
	void nectar_rtc_clear_status(void);
	
	//disable RTC interrupt
	bool rtc_disable_all_interrupt(void);
	
	//disable periodic timer
	void nectar_rtc_disable_perioidc_timer(void);
	
	//check if RTC is onboard or connected via TWI
	bool detect_rtc_3028(void);
	
	//RTC is also the source of 32KHz clock.. call this to disable it (enabled by default)
	void disable_rtc_clockout(void);
	
	//called before going to deep sleep
	bool nectar_rtc_sleep(void);
	
	//bringup tests
	//bringup without RTC interrrupt
	bool nectar_rtc_bringup_test(void);
	
	//test with RTC interrupt enabled (needs GPIO connected and configured
	bool nectar_rtc_interrupt_bringup_test(void);	
	