/**
 * Copyright (c) 2020 Nectar Inc
 * All_Rights_Reserved.
 * 
 */


#include "nrf_drv_spi.h"


#include "nectar_skyy.h"

//async spi with a interrupt handler.. otherwise spi read/writes will be blocking affairs
#define NECTAR_SPI_ASYNC 1

static const uint8_t CMD_DUMMY_BYTE = 0xFF;
static bool spi_init = false; //flag to indicate if SPI is initialized

#define SPI_INSTANCE 0 /**< SPI instance index. */
//static const nrf_drv_spi_t spi = NRF_DRV_SPI_INSTANCE(SPI_INSTANCE);       /**< SPI instance. */
nrf_drv_spi_t spi = NRF_DRV_SPI_INSTANCE(SPI_INSTANCE);
volatile bool spi_xfer_done = false; /**< Flag used to indicate that SPI instance completed the transfer. */

#define TEST_STRING "Nectarskyy"
static uint8_t m_tx_buf[] = TEST_STRING;         /**< TX buffer. */
static int8_t m_rx_buf[sizeof(TEST_STRING) + 1]; /**< RX buffer. */
static uint8_t m_length = sizeof(m_tx_buf);      /**< Transfer length. */

static uint8_t m_tx_buf_burst[24] = {0};                /**< TX buffer. */
static int8_t m_rx_buf_burst[25];                       /**< RX buffer. */
static uint8_t m_length_burst = sizeof(m_tx_buf_burst); /**< Transfer length. */

/**
 * @brief SPI user event handler.
 * @param event
 */
#if NECTAR_SPI_ASYNC
void spi_event_handler(nrf_drv_spi_evt_t const *p_event, void *p_context) {
  spi_xfer_done = true;
  //NRF_LOG_INFO("Transfer completed.");
}
#endif

uint8_t nectar_spi_readRegister8(uint8_t addr) {
  //NRF_LOG_RAW_INFO("readRegister8\r\n");
  spi_xfer_done = false;
  m_tx_buf[0] = (addr | 0x80);
  m_tx_buf[1] = CMD_DUMMY_BYTE;
  m_length = 2;
  memset(m_rx_buf, 0, m_length);

  APP_ERROR_CHECK(nrf_drv_spi_transfer(&spi, m_tx_buf, m_length, m_rx_buf, m_length));

#if NECTAR_SPI_ASYNC
  while (!spi_xfer_done) {
    __WFE();
  }
#endif
  return m_rx_buf[1];
}

void nectar_spi_writeRegister8(uint8_t addr, uint8_t value) {
  spi_xfer_done = false;
  //NRF_LOG_RAW_INFO("writeRegister8\r\n");
  //m_tx_buf[0] = (addr & LIS_WRITE_MASK);
  m_tx_buf[0] = addr;
  m_tx_buf[1] = value;
  m_length = 2; //we only write and don;t care about reading

  APP_ERROR_CHECK(nrf_drv_spi_transfer(&spi, m_tx_buf, m_length, m_rx_buf, 0));//m_length));
#if NECTAR_SPI_ASYNC
  while (!spi_xfer_done) {
    __WFE();
  }
#endif
}


void nectar_spi_init(void) {

  if (spi_init) {
    //spi is already initialized
    return;
  }

  nrf_drv_spi_config_t spi_config = NRF_DRV_SPI_DEFAULT_CONFIG;
  spi_config.ss_pin = SPI_SS_PIN;
  spi_config.miso_pin = SPI_MISO_PIN;
  spi_config.mosi_pin = SPI_MOSI_PIN;
  spi_config.sck_pin = SPI_SCK_PIN;
  spi_config.mode = NRF_DRV_SPI_MODE_0; //NRF_DRV_SPI_MODE_3,
  spi_config.frequency = NRF_SPI_FREQ_4M; //NRF_DRV_SPI_FREQ_125K; //NRF_DRV_SPI_FREQ_4M;
  spi_config.bit_order = NRF_DRV_SPI_BIT_ORDER_MSB_FIRST;
#if NECTAR_SPI_ASYNC
  APP_ERROR_CHECK(nrf_drv_spi_init(&spi, &spi_config, spi_event_handler, NULL));
#else
  APP_ERROR_CHECK(nrf_drv_spi_init(&spi, &spi_config, NULL, NULL));
#endif
  spi_init = true;
}

bool nectar_spi_sleep(void) {
  //uninit returns nothing for some reason
  nrf_drv_spi_uninit(&spi);
  spi_init = false;
  return true;
}